@@ -27,7 +27,13 @@ my $q   = $nes->{'query'}->{'q'};
 my $cgi = $nes->{'query'}->{'CGI'};
 my $nes_tags  = {};
 
-sleep 1;
+select(undef, undef, undef, 0.5);
+
+$nes_tags->{'HTTP-headers'}  = "Cache-control: max-age=0\n";
+$nes_tags->{'HTTP-headers'} .= "Cache-control: no-cache\n";
+$nes_tags->{'HTTP-headers'} .= "Expires: Mon, 1 Jan 1900 00:00:00 GMT\n";
+$nes_tags->{'HTTP-headers'} .= "Content-type: text/html; charset=utf-8\n\n";
+
 $nes_tags->{'time'}  = time;
 
 foreach my $param ( $cgi->param ) {
